.. note::

   This page is a reference documentation. It only explains the
   function signature, and not how to use it. Please refer to the
   :ref:`user guide <quickstart>` for the big picture.


{{ fullname }}
{{ underline }}

.. currentmodule:: {{ module }}

.. autofunction:: {{ objname }}

.. include:: {{module}}.{{objname}}.examples

.. raw:: html

    <div style='clear:both'></div>
